# qytorch

Quaternion Torch

A python library which has quaternion versions of some of the mostly used libraries in torch.nn. It supports all of the features of the supported layers. Main advantage of quaternion layers is that, it has only 1/4th the number of weights compared to it's real counterpart.
